Skip to contents

Clinical laboratories including demographics and the type of testing services the facility provides.

Usage

clia(
  name = NULL,
  ccn = NULL,
  clia = NULL,
  certificate = NULL,
  accrediting = NULL,
  multi = NULL,
  city = NULL,
  state = NULL,
  active = NULL,
  eligible = NULL,
  count = FALSE
)

Arguments

name

<chr> Provider/Laboratory name

ccn

<chr> 10-digit CMS Certification Number

clia

<chr> 6-digit CMS Certification Number

certificate

<enum> CLIA certificate type (see Details):

  • "wav" = Waiver

  • "ppm" = Provider-Performed Microscopy (PPM)

  • "reg" = Registration

  • "cmp" = Compliance

  • "acr" = Accreditation

accrediting

<enum> CLIA accrediting organization (see Details):

  • "a2la" = American Association for Laboratory Accreditation

  • "aabb" = Association for the Advancement of Blood & Biotherapies

  • "aoa" = American Osteopathic Association

  • "ashi" = American Society for Histocompatibility & Immunogenetics

  • "cap" = College of American Pathologists

  • "cola" = Commission on Office Laboratory Accreditation

  • "jcaho" = The Joint Commission

multi

<enum> Single site CLIA multiple-site exceptions:

  • "applied" = Applied for to cover multiple testing locations

  • "campus" = Hospital with several labs on single hospital campus

  • "non" = Multiple sites with non-profit, federal, state or local government status (limited public health testing)

  • "temp" = Lab with multiple temporary testing sites

city, state

<chr> Lab city, state

active

<lgl> Return only active labs

eligible

<lgl> Indicates lab is eligible to participate in Medicare/Medicaid.

count

<lgl> Return the total row count

Value

A tibble containing the search results.

CLIA

CMS regulates all laboratory testing (except research) performed on humans in the U.S. through the Clinical Laboratory Improvement Amendments. In total, CLIA covers approximately 320,000 laboratory entities.

Although all clinical laboratories must be properly certified to receive Medicare or Medicaid payments, CLIA has no direct Medicare or Medicaid program responsibilities.

Certification

There are five CLIA certificate types, all of which are effective for a period of two years. They are as follows, in order of increasing complexity:

  1. Waiver: Laboratory can only perform waived tests, those that are simple to perform. Although routine inspections are not conducted, 2% are visited annually to ensure quality. Does not waive the lab from all CLIA requirements.

  2. Provider-Performed Microscopy (PPM): In addition to waived tests, a physician, mid-level practitioner or dentist can perform limited tests of moderate complexity requiring microscopic examination. No routine inspections are conducted.

  3. Registration: Laboratory has applied for a Compliance or Accreditation certificate, enabling it to conduct moderate/high complexity testing until the survey is completed. Includes PPM and waived testing.

  4. Compliance: Allows the laboratory to conduct moderate/high complexity testing and is issued after an inspection finds the lab to be in compliance with all applicable CLIA requirements. Includes PPM and waived testing.

  5. Accreditation: Exactly the same as Compliance, except that the laboratory is accredited by one of the CMS-approved organizations:

Examples

clia(count = TRUE)
#>  clia | 681,059 rows | 137 pages
clia(certificate = c("acr", "reg"), city = "Valdosta", state = "GA")
#>  clia returned 18 results
#> # A tibble: 18 × 20
#>    name        ccn   clia  status  labs sites certificate address fac_type owner
#>  * <chr>       <chr> <chr> <chr>  <int> <int> <chr>       <chr>   <chr>    <chr>
#>  1 SGMC HEALTH 11D0… NA    Active     1     0 Accreditat… 2501 N… Hospital [GOV…
#>  2 SGMC- SMIT… 11D0… NA    Active     1     0 Accreditat… 4280 N… ASC      [GOV…
#>  3 SMITH & DE… 11D0… NA    Uncon…     0     0 Registrati… 2910 N… Physici… Prop…
#>  4 QUEST DIAG… 11D0… NA    Uncon…     2     0 Accreditat… 341 NO… Indepen… Prop…
#>  5 SOUTH GA M… 11D0… NA    Active     0     0 Accreditat… 2501 N… Other    [GOV…
#>  6 NORTHSIDE … 11D0… NA    Term …     0     0 Accreditat… 201 PE… Physici… Prop…
#>  7 SOUTH GEOR… 11D0… NA    Uncon…     0     0 Registrati… 201 PE… Physici… Prop…
#>  8 SOUTHERN P… 11D0… NA    Nonpa…     0     0 Registrati… 2740 M… Physici… Prop…
#>  9 VALDOSTA C… 11D1… NA    Active    15     0 Accreditat… 2841 N… Communi… [GOV…
#> 10 ALLEGIANT … 11D1… NA    Term …     4     0 Accreditat… 5101 N… Indepen… Prop…
#> 11 CARE MEDIC… 11D2… NA    Active     1     0 Accreditat… 2804-C… Other    Prop…
#> 12 GULF COAST… 11D2… NA    Term …     0     0 Registrati… 2804 N… Physici… Prop…
#> 13 BPC PLASMA… 11D2… NA    Active     1     0 Accreditat… 311 N … Other    Prop…
#> 14 SOUTH GEOR… 11D2… NA    Active     2     0 Accreditat… 3312 N… Indepen… Prop…
#> 15 SGMC POINT… 11D2… NA    Term …     2     0 Accreditat… 2501 N… Hospital [GOV…
#> 16 SGMC FAMIL… 11D2… NA    Term …     2     0 Accreditat… 3386 G… Physici… [GOV…
#> 17 OCTAPHARMA… 11D2… NA    Active     0     0 Accreditat… 1713 N… Other    Prop…
#> 18 VEEDHATA O… 11D2… NA    Active     3     0 Accreditat… 3386 G… Indepen… Prop…
#> # ℹ 10 more variables: action <chr>, cert_date <date>, eff_date <date>,
#> #   term_date <date>, elig <int>, city <chr>, state <chr>, zip <chr>,
#> #   multi <chr>, accredit <chr>
clia(accrediting = c("cap", "cola", "jcaho"))
#>  clia returned 1 result
#> # A tibble: 1 × 20
#>   name  ccn   clia  status  labs sites certificate address fac_type owner action
#> * <chr> <chr> <chr> <chr>  <int> <int> <chr>       <chr>   <chr>    <chr> <chr> 
#> 1 LEXI… 42D0… NA    Active     1     0 Accreditat… 2720 S… Hospital [GOV… NA    
#> # ℹ 9 more variables: cert_date <date>, eff_date <date>, term_date <date>,
#> #   elig <int>, city <chr>, state <chr>, zip <chr>, multi <chr>, accredit <chr>