Information on providers and suppliers currently revoked from the Medicare program.
Usage
revoked(
npi = NULL,
enid = NULL,
first = NULL,
last = NULL,
org_name = NULL,
multi = NULL,
state = NULL,
prov_desc = NULL,
reason = NULL,
start_year = NULL,
end_year = NULL,
count = FALSE
)Arguments
- npi
<int>National Provider Identifier- enid
<chr>Medicare Enrollment ID- first, last
<chr>Individual provider name- org_name
<chr>Organization name- multi
<lgl>Provider has multiple NPIs- state
<chr>Enrollment state abbreviation- prov_desc
<chr>Provider type enrollment description- reason
<chr>Reason for revocation- start_year, end_year
<int>year of revocation/expiration- count
<lgl>Return the total row count
Value
A tibble containing the search results.
Details
The Revoked Medicare Providers and Suppliers dataset contains information on providers and suppliers who are revoked and under a current re-enrollment bar. This dataset includes provider and supplier names, NPIs, revocation authorities pursuant to 42 CFR  424.535, revocation effective dates, and re-enrollment bar expiration dates. This dataset is based on information gathered from the Provider Enrollment, Chain and Ownership System (PECOS).
Reasons
 424.535 Revocation of enrollment in the Medicare program.
Noncompliance
Business Location Not Properly Licensed
Enrollment Requirements
Not Professionally Licensed
Provider/Supplier Type Requirements Not Met
DME Standards Not Met
IDTF Standards Not Met
Provider Or Supplier Conduct
Exclusion
Other
Felonies
False Or Misleading Information
On-Site Review
Grounds related to provider and supplier screening requirements
Misuse of billing number
Abuse Of Billing Privileges
Pattern Or Practice
Failure To Report
Failure To Document
Initial reserve operating funds
Other Program Termination - Medicaid - Other Federal Health Care Program
Prescribing Authority
Improper Prescribing Practices
False Claims Act (FCA)
Reserved
Debt Referred To Treasury
Revoked Under Different Name, Numerical Identifier Or Business Identity
Affiliation That Poses An Undue Risk
Billing from non-compliant location
Abusive ordering, certifying, referring, or prescribing of Part A or B services, items or drugs
Patient Harm
Violation Of Provider And Supplier Standards
Source: Code of Federal Regulations
Examples
revoked(count = TRUE)
#> ◼ revoked | 7,059 rows | 2 pages
revoked(org_name = not_blank(), count = TRUE)
#> ✔ revoked returned 3,876 results
revoked(prov_desc = contains("CARDIO"), state = excludes(c("GA", "OH")))
#> ✔ revoked returned 45 results
#> # A tibble: 45 × 11
#> org first last enid npi multi state prov_desc reason start_date
#> <chr> <chr> <chr> <chr> <int> <int> <chr> <chr> <chr> <date>
#> 1 NA JUAN KURDI I2003… 1.57e9 0 TX PRACTITI… 424.5… 2023-09-28
#> 2 NA RONALD CARLISH I2003… 1.64e9 0 CA PRACTITI… 424.5… 2022-12-13
#> 3 NA STEVE NOZAD I2003… 1.96e9 0 NY PRACTITI… 424.5… 2020-10-30
#> 4 NA RAED JITAN I2004… 1.03e9 0 WV PRACTITI… 424.5… 2020-02-14
#> 5 NA RAYMOND CATANIA I2004… 1.02e9 0 NJ PRACTITI… 424.5… 2021-03-08
#> 6 NA ROBERT VACCARINO I2004… 1.92e9 0 NY PRACTITI… 424.5… 2023-08-20
#> 7 NA STEVEN HEFTER I2004… 1.61e9 0 AL PRACTITI… 424.5… 2017-12-01
#> 8 NA BRYAN PERRY I2004… 1.24e9 0 OK PRACTITI… 424.5… 2020-05-21
#> 9 NA KLAUS RENTROP I2005… 1.19e9 0 NY PRACTITI… 424.5… 2023-09-15
#> 10 NA JOHN MCCLURE I2005… 1.43e9 0 MI PRACTITI… 424.5… 2022-11-02
#> # ℹ 35 more rows
#> # ℹ 1 more variable: end_date <date>