Hospitals currently enrolled in Medicare. Data includes the hospital's sub-group types, legal business name, doing-business-as name, organization type and address.
A list of all hospitals that have been registered with Medicare. The list includes addresses, phone numbers, hospital type, and overall hospital rating.
Usage
hospitals(
npi = NULL,
ccn = NULL,
pac = NULL,
enid = NULL,
org_name = NULL,
org_dba = NULL,
city = NULL,
state = NULL,
zip = NULL,
multi = NULL,
status = NULL,
org_type = NULL,
prov_type = NULL,
loc_type = NULL,
subgroup = subgroups(),
count = FALSE
)
hospitals2(
ccn = NULL,
org_name = NULL,
city = NULL,
state = NULL,
zip = NULL,
county = NULL,
hosp_type = NULL,
own_type = NULL,
rating = NULL,
count = FALSE
)Arguments
- npi
<int>National Provider Identifier- ccn
<int>CMS Certification Number- pac
<chr>PECOS Associate Control ID- enid
<chr>Medicare Enrollment ID- org_name
<chr>Legal business name- org_dba
<chr>Doing-business-as name- city, state, zip
<chr>Location city, state, zip- multi
<lgl>Does hospital have more than one NPI?- status
<enum>Organization statusP= ProprietaryN= Non-Profit
- org_type
<enum>Organization structure typecorp= Corporationother= Otherllc= LLCpart= Partnershipsole= Sole Proprietor
- prov_type
<enum>Provider type:hospital= Medicare Part A Hospitalreh= Rural Emergency Hospitalcah= Critical Access Hospital
- loc_type
<enum>Practice location typemain= Main/Primary Hospital Locationpsych= Hospital Psychiatric Unitrehab= Hospital Rehabilitation Unitswing= Hospital Swing-Bed Unitext= Opt Extension Siteother= Other Hospital Practice Location
- subgroup
<subgroups>Hospital’s subgroup/unit. Seesubgroups().- count
<lgl>Return the total row count- county
<chr>Location county- hosp_type
<enum>Provider type:acute= Acute Carecah= Critical Access Hospitalchild= Childrens' Hospitaldod= Acute Care - Department of Defenseltc= Long-termpsych= Psychiatricreh= Rural Emergency Hospitalvha= Acute Care - Veterans Administration
- own_type
<enum>Ownership type:private= Voluntary non-profit - Privateother= Voluntary non-profit - Otherchurch= Voluntary non-profit - Churchdistrict= Government - Hospital District or Authoritylocal= Government - Localfederal= Government - Federalstate= Government - Statedod= Department of Defenseprofit= Proprietaryphysician= Physiciantribal= Tribalvha= Veterans Health Administration
- rating
<int>Hospital rating; 1-5 or "Not Available"
Examples
hospitals(count = TRUE)
#> ◼ hospitals | 9,175 rows | 2 pages
hospitals(prov_type = "cah", state = "GA")
#> ✔ hospitals returned 65 results
#> ✔ Retrieving 1 page
#> ✔ hospitals2 returned 31 results
#> ✔ Retrieving 1 page
#> # A tibble: 65 × 18
#> org_name org_dba ccn npi pac enid multi inc_date org_type status
#> <chr> <chr> <chr> <int> <chr> <chr> <int> <date> <chr> <chr>
#> 1 BROOKS COU… ARCHBO… 11Z3… 1.58e9 1557… O200… 0 NA Other: … Non-P…
#> 2 HOSPITAL A… ARCHBO… 1113… 1.70e9 6002… O200… 0 NA Other: … Gover…
#> 3 HOSPITAL A… ARCHBO… 11Z3… 1.44e9 6002… O200… 0 NA Other: … Non-P…
#> 4 PUTNAM GEN… PUTNAM… 1113… 1.39e9 4688… O200… 0 1968-03-01 Other: … Gover…
#> 5 PUTNAM GEN… PUTNAM… 11Z3… 1.55e9 4688… O200… 0 1968-03-01 Other: … For-P…
#> 6 THE HOSPIT… MILLER… 1113… 1.11e9 0244… O200… 0 NA Other: … Gover…
#> 7 THE HOSPIT… MILLER… 11Z3… 1.29e9 0244… O200… 0 NA Other: … Non-P…
#> 8 PROFESSION… MOUNTA… 1113… 1.33e9 1052… O200… 0 2004-12-17 LLC Propr…
#> 9 HOSPITAL A… WILLS … 1113… 1.62e9 8628… O200… 0 NA Other: … Gover…
#> 10 HOSPITAL A… WILLS … 11Z3… 1.48e9 8628… O200… 0 NA Other: … Non-P…
#> # ℹ 55 more rows
#> # ℹ 8 more variables: address <chr>, city <chr>, state <chr>, zip <chr>,
#> # loc_type <chr>, sub_group <chr>, rating <int>, county <chr>
hospitals(
city = "Atlanta",
state = "GA",
subgroup = subgroups(acute = FALSE)
)
#> ✔ hospitals returned 12 results
#> ✔ Retrieving 1 page
#> ✔ hospitals2 returned 5 results
#> ✔ Retrieving 1 page
#> # A tibble: 12 × 18
#> org_name org_dba ccn npi pac enid multi inc_date org_type status
#> <chr> <chr> <chr> <int> <chr> <chr> <int> <date> <chr> <chr>
#> 1 SCOTTISH R… CHILDR… 1133… 1.92e9 4981… O200… 0 1915-04-10 Corpora… Volun…
#> 2 PIEDMONT H… NA 1100… 1.96e9 8628… O200… 0 1940-06-26 Corpora… Gover…
#> 3 EMORY UNIV… EMORY … 11S0… 1.44e9 3173… O200… 1 1994-03-04 Corpora… Non-P…
#> 4 EMORY UNIV… EMORY … 11T0… 1.36e9 3173… O200… 1 1994-03-04 Corpora… Non-P…
#> 5 ARTHUR M. … NA 1133… 1.69e9 2567… O200… 0 1943-09-18 Corpora… Volun…
#> 6 GRADY MEMO… GRADY … 11S0… 1.63e9 7517… O200… 0 2007-12-21 Corpora… Non-P…
#> 7 UHS OF ANC… ANCHOR… 1140… 1.02e9 4486… O201… 1 2000-06-02 Partner… Gover…
#> 8 UHS OF PEA… PEACHF… 1140… 1.09e9 9234… O201… 0 2000-06-02 Partner… Propr…
#> 9 SHEPHERD C… NA 1120… 1.04e9 1052… O201… 0 1975-04-21 Corpora… Non-P…
#> 10 ES REHABIL… EMORY … 1130… 1.55e9 1254… O201… 0 2013-10-15 LLC For-P…
#> 11 SELECT SPE… SELECT… 1120… 1.24e9 6305… O201… 0 NA LLC For-P…
#> 12 REHABILITA… REHABI… 1130… 1.54e9 5698… O202… 0 2020-10-16 LLC For-P…
#> # ℹ 8 more variables: address <chr>, city <chr>, state <chr>, zip <chr>,
#> # loc_type <chr>, sub_group <chr>, rating <int>, county <chr>